@@ -5,9 +5,15 @@
 //! ##### Subscriber count
 //!
 //! All functions that return subscriber counts only return 3-digit precision
-//! values as that is all that youtube returns. That means if channel has
+//! values as that is all that YouTube returns. That means if channel has
 //! exactly `164_583` subscribers, this library will return `164_000`.
 //!
+//! ##### Panic behavior
+//!
+//! This library should never panic. If it does, it should be reported as a
+//! bug. Panics mostly mean, that YouTube changed something that this library
+//! could not deal with.
+//!
 //! # Basic Example
 //!
 //! ```rust
@@ -24,7 +30,12 @@
 //! # }
 //! ```
 
-#![deny(missing_docs, unsafe_code, rustdoc::missing_crate_level_docs)]
+#![deny(
+    missing_docs,
+    unsafe_code,
+    missing_debug_implementations,
+    rust_2018_idioms
+)]
 
 #[macro_use]
 pub(crate) mod id;
