@@ -1,5 +1,4 @@
 pub mod browse;
 pub mod innertube;
 pub mod player_response;
-pub mod video_info;
-pub mod ytcfg;
+pub mod tv_config;
